@@ -199,9 +199,6 @@ void resync_redisplay(void);
 void resize_windows(void);
 void recenter(Window *wp);
 
-/* search.c --------------------------------------------------------------- */
-void free_search_history(void);
-
 /* term_minibuf.c --------------------------------------------------------- */
 void term_minibuf_write(const char *fmt);
 char *term_minibuf_read(const char *prompt, const char *value, Completion *cp, History *hp);
@@ -275,7 +272,7 @@ int zasprintf(char **ptr, const char *fmt, ...);
  * Declare external Zile functions.
  */
 #define X0(zile_name, c_name)			\
-	extern int F_ ## c_name(int argc, int uniarg);
+	extern int F_ ## c_name(int uniarg);
 #define X1(zile_name, c_name, k1)		\
 	X0(zile_name, c_name)
 #define X2(zile_name, c_name, k1, k2)		\
