@@ -1,6 +1,6 @@
 /* Miscellaneous Emacs functions reimplementation
    Copyright (c) 1997-2004 Sandro Sigala.  All rights reserved.
-   Copyright (c) 2003-2004 Reuben Thomas.  All rights reserved.
+   Copyright (c) 2003-2006 Reuben Thomas.  All rights reserved.
    Copyright (c) 2004 David A. Capello.  All rights reserved.
 
    This file is part of Zile.
@@ -20,7 +20,7 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: funcs.c,v 1.91 2005/08/06 16:23:29 rrt Exp $	*/
+/*	$Id: funcs.c,v 1.96 2006/01/30 15:23:00 rrt Exp $	*/
 
 #include "config.h"
 
@@ -399,6 +399,8 @@ int universal_argument(int keytype, int xarg)
       astr_cat_cstr(as, " C-u");
       if (i == 0)
         arg *= 4;
+      else
+        break;
     } else if (key == '-') {
       /* After any number && if sign doesn't change. */
       if (i == 0 && sgn > 0) {
@@ -555,7 +557,7 @@ DEFUN_INT("back-to-indentation", back_to_indentation)
 Move point to the first non-whitespace character on this line.
 +*/
 {
-  cur_bp->pt = line_beginning_position(0);
+  cur_bp->pt = line_beginning_position(1);
   while (!eolp()) {
     if (!isspace(following_char()))
       break;
@@ -600,18 +602,18 @@ static int transpose_subr(Function f)
   /* For transpose-chars. */
   if (f == F_forward_char) {
     if (eolp())
-      f(FALSE, -1);
+      f(-1);
   }
   /* For transpose-lines. */
   else if (f == F_forward_line) {
     /* If we are in first line, go to next line. */
     if (list_prev(cur_bp->pt.p) == cur_bp->lines) {
-      f(FALSE, 0);
+      f(1);
     }
   }
 
   /* Backward. */
-  if (!f(TRUE, -1)) {
+  if (!f(-1)) {
     minibuf_error("Beginning of buffer");
     free_marker(p0);
     return FALSE;
@@ -626,7 +628,7 @@ static int transpose_subr(Function f)
 
   /* Check end of buffer (only to check if we could make the
      operation). */
-  if (!f(TRUE, 2)) {
+  if (!f(2)) {
     /* For transpose-lines. */
     if (f == F_forward_line) {
       if (!seq_started) {
@@ -657,7 +659,7 @@ static int transpose_subr(Function f)
   goto_point(p1->pt);
 
   /* Forward. */
-  f(FALSE, 0);
+  f(1);
 
   /* Save and delete 1st marked region. */
   s1 = astr_new();
@@ -671,7 +673,7 @@ static int transpose_subr(Function f)
   FUNCALL(delete_region);
 
   /* Forward. */
-  f(FALSE, 0);
+  f(1);
 
   /* For transpose-lines. */
   if (f == F_forward_line) {
@@ -682,7 +684,7 @@ static int transpose_subr(Function f)
     set_mark();
 
     /* Backward. */
-    f(TRUE, -1);
+    f(-1);
     p2 = point_marker();
 
     /* Save and delete the marked region. */
@@ -1136,8 +1138,10 @@ Move backward to start of paragraph.  With argument N, do it N times.
     return FUNCALL_ARG(forward_paragraph, -uniarg);
 
   do {
-    while (previous_line() && is_empty_line());
-    while (previous_line() && !is_empty_line());
+    while (is_empty_line() && previous_line())
+      ;
+    while (!is_empty_line() && previous_line())
+      ;
   } while (--uniarg > 0);
 
   FUNCALL(beginning_of_line);
@@ -1155,8 +1159,10 @@ Move forward to end of paragraph.  With argument N, do it N times.
     return FUNCALL_ARG(backward_paragraph, -uniarg);
 
   do {
-    while (next_line() && is_empty_line());
-    while (next_line() && !is_empty_line());
+    while (is_empty_line() && next_line())
+      ;
+    while (!is_empty_line() && next_line())
+      ;
   } while (--uniarg > 0);
 
   if (is_empty_line())
