@@ -1,21 +1,19 @@
-/*	$Id: tbl_funcs.h,v 1.23.2.1 2005/01/16 20:57:47 rrt Exp $	*/
+/*	$Id: tbl_funcs.h,v 1.35 2005/05/16 23:11:17 rrt Exp $	*/
 
 /*
  * Add an entry to this list for declaring a new function.
  * X0 means no key binding, X1 means one key binding, etc.
  *
  * Please remember to keep in sync with the Texinfo documentation
- * `../doc/zile.texi' and the manual page `zile.1.in'.
+ * `../doc/zile.texi'.
  */
 
 X0("auto-fill-mode", auto_fill_mode)
 X1("back-to-indentation", back_to_indentation,		"\\M-m")
 X2("backward-char", backward_char,			"\\C-b", "\\LEFT")
 X1("backward-delete-char", backward_delete_char,	"\\BS")
-X1("backward-kill-sentence", backward_kill_sentence,	"\\C-x\\DEL")
 X2("backward-kill-word", backward_kill_word,		"\\M-\\DEL", "\\M-\\BS")
 X1("backward-paragraph", backward_paragraph,		"\\M-{")
-X1("backward-sentence", backward_sentence,		"\\M-a")
 X1("backward-sexp", backward_sexp,			"\\C-\\M-b")
 X1("backward-word", backward_word,			"\\M-b")
 X1("beginning-of-buffer", beginning_of_buffer,		"\\M-<")
@@ -49,7 +47,6 @@ X2("find-file", find_file,				"\\C-x\\C-f", "\\F2")
 X2("forward-char", forward_char,			"\\C-f", "\\RIGHT")
 X0("forward-line", forward_line)
 X1("forward-paragraph", forward_paragraph,		"\\M-}")
-X1("forward-sentence", forward_sentence,		"\\M-e")
 X1("forward-sexp", forward_sexp,			"\\C-\\M-f")
 X1("forward-word", forward_word,			"\\M-f")
 X0("global-set-key", global_set_key)
@@ -57,8 +54,7 @@ X0("goto-char", goto_char)
 X1("goto-line", goto_line,				"\\M-g")
 X2("help", help,					"\\C-hh", "\\F1")
 X1("help-config-sample", help_config_sample,		"\\C-hs")
-X1("help-faq", help_faq,				"\\C-hF")
-X1("help-tutorial", help_tutorial,			"\\C-ht")
+X1("help-with-tutorial", help_with_tutorial,		"\\C-ht")
 X1("indent-command", indent_command,			"\\TAB")
 X0("insert-buffer", insert_buffer)
 X1("insert-file", insert_file,				"\\C-xi")
@@ -71,14 +67,11 @@ X1("keyboard-quit", keyboard_quit,			"\\C-g")
 X1("kill-buffer", kill_buffer,				"\\C-xk")
 X2("kill-line", kill_line,				"\\C-k", "\\F6")
 X2("kill-region", kill_region,				"\\C-w", "\\F7")
-X1("kill-sentence", kill_sentence,			"\\M-k")
 X1("kill-sexp", kill_sexp,				"\\C-\\M-k")
 X1("kill-word", kill_word,				"\\M-d")
 X1("list-bindings", list_bindings,			"\\C-hb")
 X1("list-buffers", list_buffers,			"\\C-x\\C-b")
-X1("list-functions", list_functions,			"\\C-hlf")
 X1("list-registers", list_registers,			"\\C-hlr")
-X1("list-variables", list_variables,			"\\C-hlv")
 X1("mark-whole-buffer", mark_whole_buffer,		"\\C-xh")
 X1("mark-paragraph", mark_paragraph,			"\\M-h")
 X1("mark-sexp", mark_sexp,				"\\C-\\M-@")
@@ -110,7 +103,7 @@ X2("set-mark-command", set_mark_command,		"\\C-@", "\\F5")
 X0("set-variable", set_variable)
 X1("shell-command", shell_command,			"\\M-!")
 X1("shell-command-on-region", shell_command_on_region,	"\\M-|")
-X1("shrink-window", shrink_window,			"\\M-s")
+X0("shrink-window", shrink_window)
 X1("split-window", split_window,			"\\C-x2")
 X1("start-kbd-macro", start_kbd_macro,			"\\C-x(")
 X2("suspend-zile", suspend_zile,			"\\C-x\\C-z", "\\C-z")
@@ -128,6 +121,8 @@ X1("universal-argument", universal_argument,		"\\C-u")
 X0("untabify", untabify)
 X1("upcase-region", upcase_region,			"\\C-x\\C-u")
 X1("upcase-word", upcase_word,				"\\M-u")
+X1("view-zile-FAQ", view_zile_FAQ,			"\\C-hF")
+X1("where-is", where_is,				"\\C-hw")
 X1("write-file", write_file,				"\\C-x\\C-w")
 X2("yank", yank,					"\\C-y", "\\F8")
 X0("zile-version", zile_version)
